@@ -1,6 +1,8 @@
 """This defines a basic wsgi application that provides RESTful routing."""
 
+from werkzeug.exceptions import HTTPException
 from werkzeug.exceptions import MethodNotAllowed
+from werkzeug.exceptions import InternalServerError
 from werkzeug.wrappers import Request
 
 
@@ -48,15 +50,28 @@ class RestApplication(object):
         handler_endpoint = Endpoint()
 
         try:
+
             handler_method = getattr(handler_endpoint, verb)
 
         except AttributeError:
+
             raise MethodNotAllowed()
 
         for hook in self.pre_hooks:
+
             hook(request)
 
-        response = handler_method(request, **kwargs)
+        try:
+
+            response = handler_method(request, **kwargs)
+
+        except HTTPException as e:
+
+            response = e
+
+        except:
+
+            response = InternalServerError(description=unicode(e))
 
         for hook in self.post_hooks:
 
